@@ -1115,7 +1115,7 @@ do_action (int type, Acme *acme)
 		do_www_action (acme, "http://www.gnomedesktop.org");
 		break;
 	case CALCULATOR_KEY:
-		execute ("gnome-calculator", FALSE);
+		execute ("gcalctool", FALSE);
 		break;
 	case RECORD_KEY:
 		execute ("gnome-sound-recorder", FALSE);
